@@ -13,7 +13,7 @@ class Command(BaseCommand):
         generate_ts(fn)
         for line in fileinput.input(fn, inplace=True):
             line = line.replace('Serializer {', ' {')
-            line = line.replace('interface ', 'interface I')
+            line = line.replace('interface ', 'interface IApi')
             if ':' in line:
                 split_lines = line.split(':')
                 var_name = humps.camelize(split_lines[0])
